@@ -1,3 +1,6 @@
+#' @export
+pyMTurkR <- new.env() 
+
 .onLoad <- function(libname, pkgname){
   if (is.null(getOption("pyMTurkR.sandbox"))) {
       options(pyMTurkR.sandbox = TRUE)     # sandbox logical
@@ -5,5 +8,4 @@
   if (is.null(getOption("pyMTurkR.verbose"))) {
       options(pyMTurkR.verbose = TRUE)      # print logical
   }
-  pyMTurkR <<- new.env()
 }
